pub struct CurrencyInfo {
pub alphabetic_code: String,
pub name: String,
pub numeric_code: Option<u16>,
pub symbol: Option<String>,
pub standards_entities: Vec<String>,
pub subdivisions: Vec<Subdivision>,
}Expand description
A representation of registered currency data that maintained by ISO.
Fields
alphabetic_code: StringThe ISO 4217 registered 3-character currency code.
name: StringThe registered name, in English, of the currency.
numeric_code: Option<u16>The registered numeric curency code, if it has one.
symbol: Option<String>The localized symbol used to represent the currency, if known.
standards_entities: Vec<String>These correspond approximately to countries using this currency.
subdivisions: Vec<Subdivision>The, possibly empty set of subdivisions for this currency.